Crate device_driver

Crate device_driver 

Device driver toolkit

crates.io crates.io Documentation matrix

A toolkit to write better device drivers, faster.

Head over to the website to learn about how to use the project to build your own device drivers.

See the readme in root of the repo for more project information.

This is the Rust runtime of device-driver and the main public crate you should use.

Structs

BufferOperation
Intermediate type for doing buffer operations
BulkRegisterOperation
A register operation for reading or writing multiple registers in one transaction
CommandOperation
Intermediate type for doing command operations
ConversionError
The error returned by the generated TryFroms. It contains the base type of the enum.
FieldsetMetadata
Metadata about fieldsets
Plan
A plan that is used for bulk-reads and writes.
RegisterOperation
Object that performs actions on the device in the context of a register

Enums

ByteOrder
Value representing the byte order

Traits

Address
A trait implemented for the types that can be used as an address
AsyncBufferInterface
A trait to represent the interface to the device.
AsyncCommandInterface
A trait to represent the interface to the device.
AsyncRegisterInterface
A trait to represent the interface to the device.
Block
Trait implemented on every generated block/device.
BufferInterface
A trait to represent the interface to the device.
BufferInterfaceBase
Common properties shared by BufferInterface & AsyncBufferInterface
CommandInterface
A trait to represent the interface to the device.
CommandInterfaceBase
Common properties shared by CommandInterface & AsyncCommandInterface
Fieldset
Safety
RegisterInterface
A trait to represent the interface to the device.
RegisterInterfaceBase
Common properties shared by RegisterInterface & AsyncRegisterInterface