Device driver toolkit
A toolkit to write better device drivers, faster.
Head over to the website to learn about how to use the project to build your own device drivers.
See the readme in root of the repo for more project information.
This is the Rust runtime of device-driver and the main public crate you should use.
Structs
- Buffer
Operation - Intermediate type for doing buffer operations
- Bulk
Register Operation - A register operation for reading or writing multiple registers in one transaction
- Command
Operation - Intermediate type for doing command operations
- Conversion
Error - The error returned by the generated
TryFroms. It contains the base type of the enum. - Fieldset
Metadata - Metadata about fieldsets
- Plan
- A plan that is used for bulk-reads and writes.
- Register
Operation - Object that performs actions on the device in the context of a register
Enums
- Byte
Order - Value representing the byte order
Traits
- Address
- A trait implemented for the types that can be used as an address
- Async
Buffer Interface - A trait to represent the interface to the device.
- Async
Command Interface - A trait to represent the interface to the device.
- Async
Register Interface - A trait to represent the interface to the device.
- Block
- Trait implemented on every generated block/device.
- Buffer
Interface - A trait to represent the interface to the device.
- Buffer
Interface Base - Common properties shared by
BufferInterface&AsyncBufferInterface - Command
Interface - A trait to represent the interface to the device.
- Command
Interface Base - Common properties shared by
CommandInterface&AsyncCommandInterface - Fieldset
- Safety
- Register
Interface - A trait to represent the interface to the device.
- Register
Interface Base - Common properties shared by
RegisterInterface&AsyncRegisterInterface