pub trait BufferInterface: BufferInterfaceBase {
// Required methods
fn write(
&mut self,
address: Self::AddressType,
buf: &[u8],
) -> Result<usize, Self::Error>;
fn flush(&mut self, address: Self::AddressType) -> Result<(), Self::Error>;
fn read(
&mut self,
address: Self::AddressType,
buf: &mut [u8],
) -> Result<usize, Self::Error>;
}Expand description
A trait to represent the interface to the device.
This is called to read from and write to buffers.
Required Methods
Sourcefn write(
&mut self,
address: Self::AddressType,
buf: &[u8],
) -> Result<usize, Self::Error>
fn write( &mut self, address: Self::AddressType, buf: &[u8], ) -> Result<usize, Self::Error>
Write to the buffer with the given address.
This interface must adhere to [embedded_io::Write::write].
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".